@@ -1,5 +1,5 @@
 /* test_libFLAC - Unit tester for libFLAC
- * Copyright (C) 2002,2003,2004,2005,2006  Josh Coalson
+ * Copyright (C) 2002,2003,2004,2005,2006,2007  Josh Coalson
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -78,12 +78,12 @@ static FLAC__bool die_s_(const char *msg, const FLAC__StreamEncoder *encoder)
 	return false;
 }
 
-static void init_metadata_blocks_()
+static void init_metadata_blocks_(void)
 {
 	mutils__init_metadata_blocks(&streaminfo_, &padding_, &seektable_, &application1_, &application2_, &vorbiscomment_, &cuesheet_, &picture_, &unknown_);
 }
 
-static void free_metadata_blocks_()
+static void free_metadata_blocks_(void)
 {
 	mutils__free_metadata_blocks(&streaminfo_, &padding_, &seektable_, &application1_, &application2_, &vorbiscomment_, &cuesheet_, &picture_, &unknown_);
 }
@@ -489,7 +489,7 @@ static FLAC__bool test_stream_encoder(Layer layer, FLAC__bool is_ogg)
 	return true;
 }
 
-FLAC__bool test_encoders()
+FLAC__bool test_encoders(void)
 {
 	FLAC__bool is_ogg = false;
 
