@@ -1,5 +1,5 @@
 /* test_libFLAC - Unit tester for libFLAC
- * Copyright (C) 2004,2005,2006  Josh Coalson
+ * Copyright (C) 2004,2005,2006,2007  Josh Coalson
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -185,7 +185,7 @@ static struct {
 	{ 5, (const FLAC__byte*)"a=\xe1\xa5\x80", true  }
 };
 
-FLAC__bool test_format()
+FLAC__bool test_format(void)
 {
 	unsigned i;
 
